package com.qmth.distributed.print.api.mark;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.alibaba.fastjson.JSONArray;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.entity.SysConfig;
import com.qmth.teachcloud.common.service.CommonCacheService;
import com.qmth.teachcloud.mark.bean.scananswer.SheetUploadVo;
import com.qmth.teachcloud.mark.bean.scanpackage.ScanPackageFindVo;
import com.qmth.teachcloud.mark.bean.scanpackage.ScanPackageQuery;
import com.qmth.teachcloud.mark.bean.scanpackage.ScanPackageVo;
import com.qmth.teachcloud.mark.service.ScanPackageService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * <p>
 * 签到表 前端控制器
 * </p>
 *
 * @author xf
 * @since 2023-09-22
 */
@Api(tags = "扫描-签到表")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_SCAN + "/package")
public class ScanPackageController {
	@Autowired
	private CommonCacheService commonCacheService;
	@Autowired
	private ScanPackageService scanPackageService;

	@ApiOperation(value = "签到表条码识别坐标获取")
	@RequestMapping(value = "position/get", method = RequestMethod.POST)
	public JSONArray positionGet() {
		SysConfig sysConfig = commonCacheService.addSysConfigCache(SystemConstant.PACKAGE_BARCODE_POSITION);
		String value = sysConfig.getConfigValue();
		JSONArray ja = JSONArray.parseArray(value);
		return ja;
	}

	@ApiOperation(value = "签到表扫描图片上传")
	@RequestMapping(value = "image/upload", method = RequestMethod.POST)
	public SheetUploadVo imageUpload(@RequestParam Long examId, @RequestParam String packageCode,
			@RequestParam Integer packageNo, @RequestParam MultipartFile file, @RequestParam String md5) {
		return scanPackageService.imageUpload(examId, packageCode, packageNo, file, md5);
	}

	@ApiOperation(value = "签到表扫描结果列表")
	@RequestMapping(value = "image/list", method = RequestMethod.POST)
	public IPage<ScanPackageVo> imagePage(@Validated ScanPackageQuery query) {
		return scanPackageService.imagePage(query);
	}

	@ApiOperation(value = "签到表编号查询")
	@RequestMapping(value = "find", method = RequestMethod.POST)
	public ScanPackageFindVo find(@RequestParam Long examId, @RequestParam String packageCode) {
		return scanPackageService.find(examId, packageCode);
	}

	@ApiOperation(value = "签到表详情")
	@RequestMapping(value = "image/get", method = RequestMethod.POST)
	public List<String> imageGet(@RequestParam Long examId, @RequestParam String coursePaperId,
			@RequestParam String packageCode) {
		return scanPackageService.imageGet(examId,coursePaperId, packageCode);
	}
}
